Welcome to gMeterPy's documentation!
====================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :hidden:

   install.rst
   api/index.rst
   contributing.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
